@@ -7,7 +7,7 @@ TMPDIR="${TMPDIR:-/tmp}"
 TMPDIR="${TMPDIR%/}"
 export TMPDIR
 
-export BRAT_LIB="/usr/lib/brat"
+export BRAT_LIB="$ROOT/lib/$NAME"
 
 if [ -z "${BRAT_RUN+set}" ]; then
   export BRAT_RUN="$$"
